@@ -1,30 +1,5 @@
-/****************************************************************************
-**
-** Copyright (C) 2016 The Qt Company Ltd.
-** Contact: https://www.qt.io/licensing/
-**
-** This file is part of the test suite of the Qt Toolkit.
-**
-** $QT_BEGIN_LICENSE:GPL-EXCEPT$
-** Commercial License Usage
-** Licensees holding valid commercial Qt licenses may use this file in
-** accordance with the commercial license agreement provided with the
-** Software or, alternatively, in accordance with the terms contained in
-** a written agreement between you and The Qt Company. For licensing terms
-** and conditions see https://www.qt.io/terms-conditions. For further
-** information use the contact form at https://www.qt.io/contact-us.
-**
-** GNU General Public License Usage
-** Alternatively, this file may be used under the terms of the GNU
-** General Public License version 3 as published by the Free Software
-** Foundation with exceptions as appearing in the file LICENSE.GPL3-EXCEPT
-** included in the packaging of this file. Please review the following
-** information to ensure the GNU General Public License requirements will
-** be met: https://www.gnu.org/licenses/gpl-3.0.html.
-**
-** $QT_END_LICENSE$
-**
-****************************************************************************/
+// Copyright (C) 2016 The Qt Company Ltd.
+// SPDX-License-Identifier: LicenseRef-Qt-Commercial OR GPL-3.0-only WITH Qt-GPL-exception-1.0
 
 #include <QDomDocument>
 #include <qthread.h>
@@ -543,7 +518,7 @@ void tst_QXmlSimpleReader::inputFromString()
 void tst_QXmlSimpleReader::inputFromSocket_data()
 {
     const QStringList files = findXmlFiles(QLatin1String("encodings"));
-    QVERIFY(files.count() > 0);
+    QVERIFY(files.size() > 0);
 
     QTest::addColumn<QString>("file_name");
 
@@ -714,7 +689,7 @@ void tst_QXmlSimpleReader::reportNamespace_data() const
 QDomDocument tst_QXmlSimpleReader::fromByteArray(const QString &title, const QByteArray &ba, bool *ok)
 {
     QDomDocument doc(title);
-    *ok = doc.setContent(ba, true);
+    *ok = bool(doc.setContent(ba, QDomDocument::ParseOption::UseNamespaceProcessing));
     return doc;
 }
 
